# Reddit to epub converter

This little script allows you to convert reddit storries which are published in multiple posts to one single epub file.

## Usage

Install via `pip install reddit2epub`. It provides the cli at the command `reddit2epub --help`.